jactorch.transforms.coor.functional
===================================

.. automodule:: jactorch.transforms.coor.functional

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      apply_affine_transform
      center_crop
      crop
      denormalize_coor
      get_rotation_matrix
      hflip
      normalize_coor
      pad
      pad_multiple_of
      refresh_valid
      resize
      resized_crop
      rotate
      vflip
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: apply_affine_transform

.. autofunction:: center_crop

.. autofunction:: crop

.. autofunction:: denormalize_coor

.. autofunction:: get_rotation_matrix

.. autofunction:: hflip

.. autofunction:: normalize_coor

.. autofunction:: pad

.. autofunction:: pad_multiple_of

.. autofunction:: refresh_valid

.. autofunction:: resize

.. autofunction:: resized_crop

.. autofunction:: rotate

.. autofunction:: vflip


